==> dl.php?src=linea21_2_3_0.zip: linea21/publication/sup.php <==
<?php
/**
 * Publication module
 * 
 * Delete given publication from back-office
 * 
 * @package linea21\modules\publication
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $publication_object = new publication;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$publication_object->DeletePublication($id, $sql_object);
  
  // we remove associated tags
  if($result) {
  	include_once('../class/class.tag.php');
  	$otag = new tag();
  	$otag->deleteTagsByItem('publication', $id);
  }
  
  if($result) header("Location: ".safe_redirect($link_confirm));
  else  system_error();
}

$requete= SQL_getPublicationTitle($id);
$result=$sql_object->DBSelect($requete);

// Do record exists?
if(!isset($result[0]['publi_title'])) redirect_to('@module_default');

$publi_title=FormatText($result[0]['publi_title']);
$publi_owner=$result[0]['publi_posted_by'];

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('publication')) ReloadIndex('admin');
if ($l21auth->GetSessionElement('id')!=$publi_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div id="chemin">
	<ul>
		<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
		<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','publication'); ?></a></li>
		<li><span><?php echo formatnavTitle(_t('publication','sup')." : ". $publi_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
	<?php echo "<h2>".formatTitleh2($publi_title)."</h2>"; ?>
	<form id="suppubli" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>"	method="post">
		<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>
		<div>
			<input name="id" type="hidden" value="<?php echo $id; ?>" />
			<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
			<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
			<?php echo cancel_button('javascript:history.go(-1);'); ?>
			<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
		</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->

==> dl.php?src=linea21_2_5_0.zip: linea21/publication/sup.php <==
<?php
/**
 * Publication module
 * 
 * Delete given publication from back-office
 * 
 * @package linea21\modules\publication
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;


if(isset($_POST['valider'])) {
  $publication_object = new publication;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$publication_object->DeletePublication($id, $sql_object);
  
  // we remove associated tags
  if($result) {
  	include_once('../class/class.tag.php');
  	$otag = new tag();
  	$otag->deleteTagsByItem('publication', $id);
  }
  
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}

$requete= SQL_getPublicationTitle($id);
$result=$sql_object->DBSelect($requete);

// Do record exists?
if(!isset($result[0]['publi_title'])) redirect_to('@module_default');

$publi_title=FormatText($result[0]['publi_title']);
$publi_owner=$result[0]['publi_posted_by'];

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('publication')) ReloadIndex('admin');
if ($l21auth->GetSessionElement('id')!=$publi_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div id="chemin">
	<ul>
		<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
		<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','publication'); ?></a></li>
		<li><span><?php echo formatnavTitle(_t('publication','sup')." : ". $publi_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
	<?php echo "<h2>".formatTitleh2($publi_title)."</h2>"; ?>
	<form id="suppubli" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>"	method="post">
		<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>
		<div>
			<input name="id" type="hidden" value="<?php echo $id; ?>" />
			<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
			<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
			<?php echo cancel_button('javascript:history.go(-1);'); ?>
			<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
		</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
